/*
 * This file is part of the xTuple ERP: PostBooks Edition, a free and
 * open source Enterprise Resource Planning software suite,
 * Copyright (c) 1999-2014 by OpenMFG LLC, d/b/a xTuple.
 * It is licensed to you under the Common Public Attribution License
 * version 1.0, the full text of which (including xTuple-specific Exhibits)
 * is available at www.xtuple.com/CPAL.  By using this software, you agree
 * to be bound by its terms.
 */

#ifndef ASSESSFINANCECHARGES_H
#define ASSESSFINANCECHARGES_H

#include "guiclient.h"
#include "xwidget.h"
#include "ui_assessFinanceCharges.h"

class assessFinanceCharges : public XWidget, public Ui::assessFinanceCharges
{
  Q_OBJECT
  
public:
  assessFinanceCharges(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
  ~assessFinanceCharges();
  
public slots:
  virtual void sFillList();
  virtual void sAssessCharges();
  
protected slots:
  virtual void languageChange();
  
};

#endif // ASSESSFINANCECHARGES_H
